Struct waker_set::WakerSet [−][src]
A set holding wakers.
Implementations
impl WakerSet[src]
pub fn new() -> WakerSet[src]
Creates a new WakerSet.
pub fn insert(&self, cx: &Context<'_>) -> usize[src]
Inserts a waker for a blocked operation and returns a key associated with it.
pub fn cancel(&self, key: usize) -> bool[src]
Removes the waker of a cancelled operation.
Returns true if another blocked operation from the set was notified.
pub fn notify_all(&self) -> bool[src]
Notifies all blocked operations.
Returns true if at least one operation was notified.